==> webkit2gtk_2.36.0.orig.tar.xz: webkitgtk-2.36.0/Source/WebCore/Modules/WebGPU/GPUTextureViewDescriptor.h <==
/*
 * Copyright (C) 2021 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include "GPUIntegralTypes.h"
#include "GPUObjectDescriptorBase.h"
#include "GPUTextureAspect.h"
#include "GPUTextureFormat.h"
#include "GPUTextureViewDimension.h"
#include <optional>
#include <pal/graphics/WebGPU/WebGPUTextureViewDescriptor.h>

namespace WebCore {

struct GPUTextureViewDescriptor : public GPUObjectDescriptorBase {
    PAL::WebGPU::TextureViewDescriptor convertToBacking() const
    {
        return {
            { label },
            format ? std::optional { WebCore::convertToBacking(*format) } : std::nullopt,
            dimension ? std::optional { WebCore::convertToBacking(*dimension) } : std::nullopt,
            WebCore::convertToBacking(aspect),
            baseMipLevel,
            mipLevelCount,
            baseArrayLayer,
            arrayLayerCount,
        };
    }

    std::optional<GPUTextureFormat> format;
    std::optional<GPUTextureViewDimension> dimension;
    GPUTextureAspect aspect { GPUTextureAspect::All };
    GPUIntegerCoordinate baseMipLevel { 0 };
    std::optional<GPUIntegerCoordinate> mipLevelCount;
    GPUIntegerCoordinate baseArrayLayer { 0 };
    std::optional<GPUIntegerCoordinate> arrayLayerCount;
};

}

==> webkit2gtk_2.48.7.orig.tar.xz: webkitgtk-2.48.7/Source/WebCore/Modules/WebGPU/GPUTextureViewDescriptor.h <==
/*
 * Copyright (C) 2021-2023 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include "GPUIntegralTypes.h"
#include "GPUObjectDescriptorBase.h"
#include "GPUTextureAspect.h"
#include "GPUTextureFormat.h"
#include "GPUTextureViewDimension.h"
#include "WebGPUTextureViewDescriptor.h"
#include <optional>

namespace WebCore {

struct GPUTextureViewDescriptor : public GPUObjectDescriptorBase {
    WebGPU::TextureViewDescriptor convertToBacking() const
    {
        return {
            { label },
            format ? std::optional { WebCore::convertToBacking(*format) } : std::nullopt,
            dimension ? std::optional { WebCore::convertToBacking(*dimension) } : std::nullopt,
            WebCore::convertToBacking(aspect),
            baseMipLevel,
            mipLevelCount,
            baseArrayLayer,
            arrayLayerCount,
        };
    }

    std::optional<GPUTextureFormat> format;
    std::optional<GPUTextureViewDimension> dimension;
    GPUTextureAspect aspect { GPUTextureAspect::All };
    GPUIntegerCoordinate baseMipLevel { 0 };
    std::optional<GPUIntegerCoordinate> mipLevelCount;
    GPUIntegerCoordinate baseArrayLayer { 0 };
    std::optional<GPUIntegerCoordinate> arrayLayerCount;
};

}
